@@ -22,11 +22,13 @@ class Params(SerializableModel):
 
 class CyclicScheduler(StandardSchedulerBase):
     class BaseLRParameter(SchedulerParameter[State, float]):
-        async def _get_from_scheduler(self, scheduler: CyclicLR) -> float:
+        @classmethod
+        async def _get_from_scheduler(cls, scheduler: CyclicLR) -> float:
             return scheduler.base_lrs[0]
 
+        @classmethod
         async def _set_in_scheduler(
-            self, scheduler: CyclicLR, value: float
+            cls, scheduler: CyclicLR, value: float
         ) -> None:
             lrs = [value] * len(scheduler.base_lrs)
             scheduler.base_lrs = lrs
@@ -34,6 +36,7 @@ class CyclicScheduler(StandardSchedulerBase):
                 for lr, group in zip(lrs, scheduler.optimizer.param_groups):
                     group["lr"] = lr
 
+        # noinspection PyMethodParameters
         @classproperty
         def schema(cls) -> Dict[str, Any]:
             return {
@@ -43,19 +46,23 @@ class CyclicScheduler(StandardSchedulerBase):
                 "default": 0.001,
             }
 
+        # noinspection PyMethodParameters
         @classproperty
         def pretty_name(cls) -> str:
             return "Base Learning Rate"
 
     class MaxLRParameter(SchedulerParameter[State, float]):
-        async def _get_from_scheduler(self, scheduler: CyclicLR) -> float:
+        @classmethod
+        async def _get_from_scheduler(cls, scheduler: CyclicLR) -> float:
             return scheduler.max_lrs[0]
 
+        @classmethod
         async def _set_in_scheduler(
-            self, scheduler: CyclicLR, value: float
+            cls, scheduler: CyclicLR, value: float
         ) -> None:
             scheduler.max_lrs = [value] * len(scheduler.max_lrs)
 
+        # noinspection PyMethodParameters
         @classproperty
         def schema(cls) -> Dict[str, Any]:
             return {
@@ -65,21 +72,25 @@ class CyclicScheduler(StandardSchedulerBase):
                 "default": 0.006,
             }
 
+        # noinspection PyMethodParameters
         @classproperty
         def pretty_name(cls) -> str:
             return "Maximum Learning Rate"
 
     class StepSizeUpParameter(SchedulerParameter[State, int]):
-        async def _get_from_scheduler(self, scheduler: CyclicLR) -> int:
+        @classmethod
+        async def _get_from_scheduler(cls, scheduler: CyclicLR) -> int:
             return int(scheduler.step_ratio * scheduler.total_size)
 
+        @classmethod
         async def _set_in_scheduler(
-            self, scheduler: CyclicLR, value: int
+            cls, scheduler: CyclicLR, value: int
         ) -> None:
-            current = await self._get_from_scheduler(scheduler)
+            current = await cls._get_from_scheduler(scheduler)
             scheduler.total_size = scheduler.total_size - current + value
             scheduler.step_ratio = value / scheduler.total_size
 
+        # noinspection PyMethodParameters
         @classproperty
         def schema(cls) -> Dict[str, Any]:
             return {
@@ -90,17 +101,20 @@ class CyclicScheduler(StandardSchedulerBase):
             }
 
     class StepSizeDownParameter(SchedulerParameter[State, int]):
-        async def _get_from_scheduler(self, scheduler: CyclicLR) -> int:
+        @classmethod
+        async def _get_from_scheduler(cls, scheduler: CyclicLR) -> int:
             return int(scheduler.total_size * (1 - scheduler.step_ratio))
 
+        @classmethod
         async def _set_in_scheduler(
-            self, scheduler: CyclicLR, value: int
+            cls, scheduler: CyclicLR, value: int
         ) -> None:
-            current = await self._get_from_scheduler(scheduler)
+            current = await cls._get_from_scheduler(scheduler)
             current_up = scheduler.step_ratio * scheduler.total_size
             scheduler.total_size = scheduler.total_size - current + value
             scheduler.step_ratio = current_up / scheduler.total_size
 
+        # noinspection PyMethodParameters
         @classproperty
         def schema(cls) -> Dict[str, Any]:
             return {
@@ -115,6 +129,7 @@ class CyclicScheduler(StandardSchedulerBase):
             State, Literal["triangular", "triangular2", "exp_range"]
         ]
     ):
+        # noinspection PyMethodParameters
         @classproperty
         def schema(cls) -> Dict[str, Any]:
             return {
@@ -129,6 +144,7 @@ class CyclicScheduler(StandardSchedulerBase):
             }
 
     class GammaParameter(SchedulerParameter[State, float]):
+        # noinspection PyMethodParameters
         @classproperty
         def schema(cls) -> Dict[str, Any]:
             return {
