@@ -10,3 +10,13 @@ class Tokenizer(ABC):
     @abstractmethod
     def decode(self, indices: List[int]) -> str:
         pass
+
+    @property
+    @abstractmethod
+    def start_token(self) -> int:
+        pass
+
+    @property
+    @abstractmethod
+    def end_token(self) -> int:
+        pass
